@@ -1,22 +1,23 @@
 #!/usr/bin/env python
 """Application controller for FastTree
 
-designed for FastTree v1.1.0 .  Also functions with v2.0.1, and v2.1.0,
+designed for FastTree v1.1.0 .  Also functions with v2.0.1, v2.1.0, and v2.1.3
 though only with basic functionality"""
 
 from cogent.app.parameters import ValuedParameter, FlagParameter, \
        MixedParameter
 from cogent.app.util import CommandLineApplication, FilePath, system, \
-       CommandLineAppResult, ResultPath, remove
+       CommandLineAppResult, ResultPath, remove, ApplicationError
 from cogent.core.tree import PhyloNode
 from cogent.parse.tree import DndParser
 from cogent.core.moltype import DNA, RNA, PROTEIN
+from cogent.core.alignment import SequenceCollection
 
 __author__ = "Daniel McDonald"
-__copyright__ = "Copyright 2007-2008, The Cogent Project"
+__copyright__ = "Copyright 2007-2012, The Cogent Project"
 __credits__ = ["Daniel McDonald", "Justin Kuczynski"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.2"
 __maintainer__ = "Daniel McDonald"
 __email__ = "mcdonadt@colorado.edu"
 __status__ = "Development"
@@ -68,7 +69,6 @@ class FastTree(CommandLineApplication):
             NOTE: Override of the base class to handle redirected output
         """
         input_handler = self.InputHandler
-        suppress_stdout = self.SuppressStdout
         suppress_stderr = self.SuppressStderr
 
         outfile = self.getTmpFilename(self.TmpDir)
@@ -144,9 +144,18 @@ def build_tree_from_alignment(aln, moltype, best_tree=False, params=None):
     if best_tree:
         params['-slow'] = True
 
+    #Create mapping between abbreviated IDs and full IDs
+    int_map, int_keys = aln.getIntMap()
+    #Create SequenceCollection from int_map.
+    int_map = SequenceCollection(int_map,MolType=moltype)
+
     app = FastTree(params=params)
     
-    result = app(aln.toFasta())
+    result = app(int_map.toFasta())
     tree = DndParser(result['Tree'].read(), constructor=PhyloNode)
+    #remap tip names
+    for tip in tree.tips():
+        tip.Name = int_keys[tip.Name]
+
     return tree
     
