@@ -1,4 +1,5 @@
 import sqlalchemy as sql
+from numpy import empty
 
 from cogent.util.table import Table
 from cogent.db.ensembl.species import Species as _Species
@@ -10,17 +11,18 @@ from cogent.db.ensembl.genome import Genome
 from cogent.db.ensembl.related_region import RelatedGenes, SyntenicRegions
 
 __author__ = "Gavin Huttley"
-__copyright__ = "Copyright 2007, The Cogent Project"
-__credits__ = ["Gavin Huttley", "Hua Ying"]
+__copyright__ = "Copyright 2007-2012, The Cogent Project"
+__credits__ = ["Gavin Huttley", "Hua Ying", "Jason Merkin"]
 __license__ = "GPL"
-__version__ = "1.4.1"
+__version__ = "1.5.2"
 __maintainer__ = "Gavin Huttley"
 __email__ = "Gavin.Huttley@anu.edu.au"
 __status__ = "alpha"
 
 class Compara(object):
     """comaparison among genomes"""
-    def __init__(self, species, Release, account=None, pool_recycle=None):
+    def __init__(self, species, Release, account=None, pool_recycle=None,
+            division=None):
         assert Release, 'invalid release specified'
         self.Release = str(Release)
         if account is None:
@@ -37,15 +39,15 @@ class Compara(object):
         self._species_db_map = None
         self._species_set = None
         self._method_species_link = None
+        self.division = division
     
     def _attach_genomes(self):
         for species in self.Species:
-            common = _Species.getCommonName(species)
-            common = common.title().replace(' ', '')
+            attr_name = _Species.getComparaName(species)
             genome = Genome(Species=species, Release=self.Release,
                             account=self._account)
             self._genomes[species] = genome
-            setattr(self, common, genome)
+            setattr(self, attr_name, genome)
     
     def __str__(self):
         my_type = self.__class__.__name__
@@ -58,7 +60,8 @@ class Compara(object):
         connection = dict(account=self._account, release=self.Release,
                         pool_recycle=self._pool_recycle)
         if self._compara_db is None:
-            self._compara_db = Database(db_type='compara', **connection)
+            self._compara_db = Database(db_type='compara',
+                                        division=self.division, **connection)
     
     def _get_compara_db(self):
         self._connect_db()
@@ -151,6 +154,10 @@ class Compara(object):
             clade_name = record['name']
             aln_name = method_link_ids[ml_id]['type']
             rows += [[ml_sp_set_id, ml_id, sp_set_id, aln_name, clade_name]]
+        
+        if rows == []:
+            rows = empty((0,len(header)))
+        
         t = Table(header=header, rows=rows, space=2, row_ids=True,
                   title='Align Methods/Clades')
         self._method_species_link = t
@@ -170,6 +177,10 @@ class Compara(object):
             "No identifier provided"
         assert Relationship is not None, "No Relationship specified"
         
+        # TODO understand why this has become necessary to suppress warnings
+        # in SQLAlchemy 0.6
+        Relationship = u'%s' % Relationship
+        
         StableId = StableId or gene_region.StableId
         
         member_table = self.ComparaDb.getTable('member')
@@ -188,7 +199,7 @@ class Compara(object):
         homology_ids = sql.select([homology_member_table.c.homology_id,
                           homology_member_table.c.member_id],
                           homology_member_table.c.member_id.in_(member_ids))
-        homology_ids =  [r['homology_id'] for r in homology_ids.execute()]
+        homology_ids = [r['homology_id'] for r in homology_ids.execute()]
         if not homology_ids:
             return None
         
@@ -208,6 +219,8 @@ class Compara(object):
         homology_ids = dict(homology_ids)
         
         if DEBUG: print "2 - homology_ids", homology_ids
+        if not homology_ids:
+            return None
         
         ortholog_ids = sql.select([homology_member_table.c.member_id,
                                 homology_member_table.c.homology_id],
@@ -216,14 +229,16 @@ class Compara(object):
         ortholog_ids = dict([(r['member_id'], r['homology_id']) \
                                       for r in ortholog_ids.execute()])
         
+        if DEBUG: print "ortholog_ids", ortholog_ids
+        if not ortholog_ids:
+            return None
+        
         # could we have more than one here?
         relationships = set()
         for memid, homid in ortholog_ids.items():
             relationships.update([homology_ids[homid][0]])
         relationships = tuple(relationships)
         
-        if DEBUG: print "ortholog_ids", ortholog_ids
-        
         gene_set = sql.select([member_table],
                 sql.and_(member_table.c.member_id.in_(ortholog_ids.keys()),
                   member_table.c.taxon_id.in_(self.taxon_id_species.keys())))
@@ -245,11 +260,17 @@ class Compara(object):
         """returns the dnafrag_id for the coordnate"""
         dnafrag_table = self.ComparaDb.getTable('dnafrag')
         genome_db_table = self.ComparaDb.getTable('genome_db')
+        
+        # column renamed between versions
+        prefix = coord.genome.Species.lower()
+        if int(self.Release) > 58:
+            prefix = _Species.getEnsemblDbPrefix(prefix)
+        
         query = sql.select([dnafrag_table.c.dnafrag_id,
                            dnafrag_table.c.coord_system_name],
                   sql.and_(dnafrag_table.c.genome_db_id ==\
-                                                genome_db_table.c.genome_db_id,
-                                genome_db_table.c.name == coord.genome.Species,
+                                            genome_db_table.c.genome_db_id,
+                                genome_db_table.c.name == prefix,
                                 dnafrag_table.c.name == coord.CoordName))
         try:
             record = asserted_one(query.execute().fetchall())
