@@ -11,11 +11,11 @@ from cogent.recalculation.definition import ParameterController
 from cogent.util.warning import discontinued, deprecated
 
 __author__ = "Peter Maxwell"
-__copyright__ = "Copyright 2007-2011, The Cogent Project"
+__copyright__ = "Copyright 2007-2012, The Cogent Project"
 __credits__ = ["Gavin Huttley", "Andrew Butterfield", "Peter Maxwell",
                     "Matthew Wakefield", "Rob Knight", "Brett Easton"]
 __license__ = "GPL"
-__version__ = "1.5.1"
+__version__ = "1.5.2"
 __maintainer__ = "Gavin Huttley"
 __email__ = "gavin.huttley@anu.edu.au"
 __status__ = "Production"
@@ -38,35 +38,49 @@ class LikelihoodFunction(ParameterController):
     def getLogLikelihood(self):
         return self.getFinalResult()
     
-    def getPsubForEdge(self, name):
+    def getPsubForEdge(self, name, **kw):
         """returns the substitution probability matrix for the named edge"""
-        array = self.getParamValue('psubs', edge=name)
+        try:
+            # For PartialyDiscretePsubsDefn
+            array = self.getParamValue('dpsubs', edge=name, **kw)
+        except KeyError:
+            array = self.getParamValue('psubs', edge=name, **kw)
         return DictArrayTemplate(self._motifs, self._motifs).wrap(array)
     
-    def getRateMatrixForEdge(self, name):
+    def getRateMatrixForEdge(self, name, **kw):
         """returns the rate matrix (Q) for the named edge
         
         Note: expm(Q) will give the same result as getPsubForEdge(name)"""
         try:
-            array = self.getParamValue('Q', edge=name)
+            array = self.getParamValue('Q', edge=name, **kw)
         except KeyError as err:
             if err[0] == 'Q' and name != 'Q':
                 raise RuntimeError('rate matrix not known by this model')
             else:
                 raise
         return DictArrayTemplate(self._motifs, self._motifs).wrap(array)
-
     
-    def getFullLengthLikelihoods(self, locus=None):
+    def _getLikelihoodValuesSummedAcrossAnyBins(self, locus=None):
         if self.bin_names and len(self.bin_names) > 1:
-            root_lh = self.getParamValue('bindex', locus=locus)
             root_lhs = [self.getParamValue('lh', locus=locus, bin=bin) for
                 bin in self.bin_names]
-            return root_lh.getFullLengthLikelihoods(*root_lhs)
+            bprobs = self.getParamValue('bprobs')
+            root_lh = bprobs.dot(root_lhs)
         else:
-            root_lht = self.getParamValue('root', locus=locus)
             root_lh = self.getParamValue('lh', locus=locus)
-            return root_lht.getFullLengthLikelihoods(root_lh)
+        return root_lh
+        
+    def getFullLengthLikelihoods(self, locus=None):
+        """Array of [site, motif] likelihoods from the root of the tree"""
+        root_lh = self._getLikelihoodValuesSummedAcrossAnyBins(locus=locus)
+        root_lht = self.getParamValue('root', locus=locus)
+        return root_lht.getFullLengthLikelihoods(root_lh)
+    
+    def getGStatistic(self, return_table=False, locus=None):
+        """Goodness-of-fit statistic derived from the unambiguous columns"""
+        root_lh = self._getLikelihoodValuesSummedAcrossAnyBins(locus=locus)
+        root_lht = self.getParamValue('root', locus=locus)
+        return root_lht.calcGStatistic(root_lh, return_table)
     
     def reconstructAncestralSeqs(self, locus=None):
         """returns a dict of DictArray objects containing probabilities
@@ -349,7 +363,7 @@ class LikelihoodFunction(ParameterController):
     def _nodeMotifProbs(self, tree, mprobs, kw):
         result = [(tree.Name, mprobs)]
         for child in tree.Children:
-            psub = self.getParamValue('psubs', edge=child.Name, **kw)
+            psub = self.getPsubForEdge(child.Name, **kw)
             child_mprobs = numpy.dot(mprobs, psub)
             result.extend(self._nodeMotifProbs(child, child_mprobs, kw))
         return result
@@ -378,18 +392,13 @@ class LikelihoodFunction(ParameterController):
         else:
             orig_ambig = {}
         
-        mprobs = self.getParamValue('mprobs',locus=locus)
-        mprobs = self._model.calcWordProbs(mprobs)
-        mprobs = dict((m, p) for (m,p) in zip(self._motifs, mprobs))
-        
         if random_series is None:
             random_series = random.Random()
             random_series.seed(seed)
             parallel.sync_random(random_series)
         
         def psub_for(edge, bin):
-            return self.getParamValue('psubs',
-                    edge=edge, bin=bin, locus=locus)
+            return self.getPsubForEdge(edge, bin=bin, locus=locus)
         
         if len(self.bin_names) > 1:
             hmm = self.getParamValue('bdist', locus=locus)
@@ -406,6 +415,9 @@ class LikelihoodFunction(ParameterController):
             motif_len = self._model.getAlphabet().getMotifLen()
             root_sequence = root_sequence.getInMotifSize(motif_len)
         else:
+            mprobs = self.getParamValue('mprobs', locus=locus, edge='root')
+            mprobs = self._model.calcWordProbs(mprobs)
+            mprobs = dict((m, p) for (m,p) in zip(self._motifs, mprobs))
             root_sequence = randomSequence(
                 random_series, mprobs, sequence_length)
         
