@@ -9,11 +9,11 @@ from cogent.core.annotation import Feature
 from cogent.core.info import Info
 
 __author__ = "Rob Knight"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2012, The Cogent Project"
 __credits__ = ["Rob Knight", "Peter Maxwell", "Matthew Wakefield",
                     "Gavin Huttley"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.2"
 __maintainer__ = "Rob Knight"
 __email__ = "rob@spot.colorado.edu"
 __status__ = "Production"
@@ -32,6 +32,9 @@ _locus_parser = FieldWrapper(locus_fields)
 #need to turn off line stripping, because whitespace is significant
 GbFinder = DelimitedRecordFinder('//', constructor=rstrip)
 
+class PartialRecordError(Exception):
+    pass
+
 def parse_locus(line):
     """Parses a locus line, including conversion of Length to an int.
     
@@ -40,7 +43,11 @@ def parse_locus(line):
     even when prior versions omitted it.
     """
     result = _locus_parser(line)
-    result['length'] = int(result['length'])
+    try:
+        result['length'] = int(result['length'])
+    except KeyError, e:
+        raise PartialRecordError, e
+
     if None in result:
         del result[None]
     return result
@@ -89,6 +96,7 @@ def block_consolidator(lines):
     """
     data = []
     first = True
+    label = None
     for line in lines:
         if first:   #find label
             line = line.split(None, 1)
@@ -182,8 +190,12 @@ def parse_feature(lines):
             curr_data = remainder
         else:
             curr_data = ' '.join(map(strip, remainder))
+        if label.lower() == 'type':
+            # some source features have /type=...
+            label = 'type_field'
         if label not in result:
             result[label.lower()] = []
+
         result[label.lower()].append(curr_data)
     return result
 
@@ -485,11 +497,19 @@ def MinimalGenbankParser(lines, handlers=handlers,\
     default_handler=generic_adaptor):
     for rec in GbFinder(lines):
         curr = {}
+        bad_record = False
         for field in indent_splitter(rec):
             first_word = field[0].split(None, 1)[0]
             handler = handlers.get(first_word, default_handler)
-            handler(field, curr)
-        yield curr
+
+            try:
+                handler(field, curr)
+            except:
+                bad_record = True
+                break
+
+        if not bad_record:
+            yield curr
 
 def parse_location_segment(location_segment):
     """Parses a location segment into its component pieces.
@@ -575,7 +595,12 @@ def RichGenbankParser(handle, info_excludes=None, moltype=None,
                                         Name=rec['locus'])
         except KeyError:
             if not skip_contigs:
-                yield rec['locus'], rec['contig']
+                if 'contig' in rec:
+                    yield rec['locus'], rec['contig']
+                elif 'WGS' in rec:
+                    yield rec['locus'], rec['WGS']
+                else:
+                    yield rec['locus'], None
             continue
         
         for feature in rec['features']:
