@@ -2,22 +2,21 @@
 from __future__ import division, with_statement
 import numpy
 Float = numpy.core.numerictypes.sctype2char(float)
-import time, logging, warnings
-import cogent.maths.optimisers
+import time, warnings
 from cogent.maths.solve import find_root
 from cogent.util import parallel
-from cogent.maths.optimiser import ParameterOutOfBoundsError
+from cogent.maths.optimisers import maximise, ParameterOutOfBoundsError
+
 
 import os
 TRACE_DEFAULT = os.environ.has_key('COGENT_TRACE')
-
-LOG = logging.getLogger('cogent')
+TRACE_SCALE = 100000
 
 __author__ = "Peter Maxwell"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2012, The Cogent Project"
 __credits__ = ["Peter Maxwell", "Gavin Huttley", "Daniel McDonald"]
 __license__ = "GPL"
-__version__ = "1.4.1"
+__version__ = "1.5.2"
 __maintainer__ = "Peter Maxwell"
 __email__ = "pm67nz@gmail.com"
 __status__ = "Production"
@@ -34,7 +33,7 @@ class OptPar(object):
     An OptPar reports changes to the ParameterValueSet for its parameter.
     """
     
-    is_const = False
+    is_constant = False
     recycled = False
     args = ()
     # Use of __slots__ here and in Cell gives 8% speedup on small calculators.
@@ -91,7 +90,7 @@ class LogOptPar(OptPar):
     
 
 class EvaluatedCell(object):
-    __slots__ = ['client_ranks', 'rank', 'calc', 'args', 'is_const',
+    __slots__ = ['client_ranks', 'rank', 'calc', 'args', 'is_constant',
         'clients', 'failure_count', 'name', 'arg_ranks',
         'consequences', 'recycled', 'default']
     
@@ -106,11 +105,11 @@ class EvaluatedCell(object):
         if recycling:
             self.args = (self,) + self.args
         
-        self.is_const = True
+        self.is_constant = True
         for arg in args:
             arg.addClient(self)
-            if not arg.is_const:
-                self.is_const = False
+            if not arg.is_constant:
+                self.is_constant = False
         
         self.clients = []
         self.client_ranks = []
@@ -124,7 +123,7 @@ class EvaluatedCell(object):
                 *[data[arg_rank] for arg_rank in self.arg_ranks])
     
     def prime(self, data_sets):
-        if self.is_const:
+        if self.is_constant:
             # Just calc once
             self.update(data_sets[0])
             for data in data_sets[1:]:
@@ -136,21 +135,21 @@ class EvaluatedCell(object):
     def reportError(self, detail, data):
         self.failure_count += 1
         if self.failure_count <= 5:
-            LOG.exception("%s in calculating %s:",
+            print ("%s in calculating %s:",
                     detail.__class__.__name__, self.name)
         if self.failure_count == 5:
-            LOG.error("Additional failures of this type will not be logged.")
+            print "Additional failures of this type will not be reported."
         if self.failure_count < 2:
-            LOG.error('%s inputs were:', len(self.arg_ranks))
+            print '%s inputs were:', len(self.arg_ranks)
             for (i, arg) in enumerate(self.arg_ranks):
-                LOG.error('%s: ' % i + repr(data[arg]))
+                print '%s: ' % i + repr(data[arg])
     
 
 class ConstCell(object):
     __slots__ = ['name', 'scope', 'value', 'rank', 'consequences', 'clients']
     
     recycled = False
-    is_const = True
+    is_constant = True
     args = ()
     
     def __init__(self, name, value):
@@ -202,13 +201,13 @@ class Calculator(object):
                     self.arg_ranks[i].append(arg.rank)
                     cell.arg_ranks.append(arg.rank)
                 
-                with parallel.mpi_context(self.remaining_parallel_context):
+                with parallel.parallel_context(self.remaining_parallel_context):
                     try:
                         cell.prime(self.cell_values)
                     except KeyboardInterrupt:
                         raise
                     except Exception, detail:
-                        LOG.exception("Failed initial calculation of %s"
+                        print ("Failed initial calculation of %s"
                                 % cell.name)
                         raise
             else:
@@ -266,8 +265,8 @@ class Calculator(object):
                     label = '[]'
                 label = '<%s> %s' % (cell.rank, label)
                 enodes.append(label)
-                all_const = all_const and cell.is_const
-                some_const = some_const or cell.is_const
+                all_const = all_const and cell.is_constant
+                some_const = some_const or cell.is_constant
             enodes = '|'.join(enodes)
             colour = ['', ' fillcolor=gray90, style=filled,'][some_const]
             colour = [colour, ' fillcolor=gray, style=filled,'][all_const]
@@ -306,41 +305,10 @@ class Calculator(object):
             time.sleep(5)
             os.remove(fn)
     
-    def getOptimiser(self, local=False, optimiser_class=None, **kw):
-        if optimiser_class is None:
-            if local:
-                optimiser_class = cogent.maths.optimisers.Powell
-            else:
-                optimiser_class = cogent.maths.optimisers.SimulatedAnnealing
-        bounds = self.getBoundsVectors()
+    def optimise(self, **kw):
         x = self.getValueArray()
-        return optimiser_class(self, x, bounds, **kw)
-    
-    def optimise(self, local=None, filename=None, interval=None,
-            show_progress=True, max_restarts=None, max_evaluations=None,
-            tolerance=1e-6, global_tolerance=1e-1, **kw):
-        """Find input values that optimise this function.
-        'local' controls the choice of optimiser, the default being to run
-        both the global and local optimisers. 'filename' and 'interval'
-        control checkpointing.  Unknown keyword arguments get passed on to
-        the optimiser(s)."""
-        # Global optimisation
-        if not local or local is None:
-            gtol = [tolerance, global_tolerance][local is None]
-            opt = self.getOptimiser(False, tolerance=gtol,
-                    max_evaluations=max_evaluations, **kw)
-            opt.setCheckpointing(filename=filename, interval=interval)
-            opt.run(show_progress=show_progress)
-        else:
-            for k in kw:
-                LOG.warning('Unused arg for local alignment: ' + k)
-        
-        # Local optimisation
-        if local or local is None:
-            opt = self.getOptimiser(True, tolerance=tolerance,
-                max_restarts=max_restarts, max_evaluations=max_evaluations)
-            opt.run(show_progress=show_progress)
-        
+        bounds = self.getBoundsVectors()
+        maximise(self, x, bounds, **kw)
         self.optimised = True
     
     def setTracing(self, trace=False):
@@ -351,14 +319,15 @@ class Calculator(object):
         if trace:
             print
             n_opars = len(self.opt_pars)
-            n_cells = len([c for c in self._cells if not c.is_const])
-            print n_opars, "OptPars and", n_cells - n_opars, "cells"
-            print self.opt_pars
-            
+            n_cells = len([c for c in self._cells if not c.is_constant])
+            print n_opars, "OptPars and", n_cells - n_opars, "derived values"
+            print 'OptPars: ', ', '.join([par.name for par in self.opt_pars])
+            print "Times in 1/%sths of a second" % TRACE_SCALE
+
             groups = []
             groupd = {}
             for cell in self._cells:
-                if cell.is_const or not isinstance(cell, EvaluatedCell):
+                if cell.is_constant or not isinstance(cell, EvaluatedCell):
                     continue
                 if cell.name not in groupd:
                     group = []
@@ -437,7 +406,8 @@ class Calculator(object):
         
         t0 = time.time()
         self.evaluations += 1
-        assert parallel.getCommunicator() is self.overall_parallel_context
+        assert parallel.getContext() is self.overall_parallel_context, (
+            parallel.getContext(), self.overall_parallel_context)
         
         # If ALL of the changes made in the last step are reversed in this step
         # then it is safe to undo them first, taking advantage of the 1-deep
@@ -484,7 +454,7 @@ class Calculator(object):
             else:
                 data[i] = v
         
-        with parallel.mpi_context(self.remaining_parallel_context):
+        with parallel.parallel_context(self.remaining_parallel_context):
             try:
                 if self.trace:
                     self.tracingUpdate(changes, program, data)
@@ -543,9 +513,8 @@ class Calculator(object):
     def tracingUpdate(self, changes, program, data):
         # Does the same thing as plainUpdate, but also produces lots of
         # output showing how long each step of the calculation takes.
-        # One line per call, '-' for undo, '+' for calculation, times
-        # in 10000ths of a second.
-        
+        # One line per call, '-' for undo, '+' for calculation
+                
         exception = None
         elapsed = {}
         for cell in program:
@@ -566,7 +535,7 @@ class Calculator(object):
                 edge_width = min(len(text), (width - 4 - 3)) // 2
                 elipsis = ['   ','...'][not not text.strip()]
                 text = text[:edge_width] + elipsis + text[-edge_width:]
-            tds.append('%s%4s' % (text, int((10000*(elap))) or ''))
+            tds.append('%s%4s' % (text, int(TRACE_SCALE*elap+0.5) or ''))
         
         par_descs = []
         for (i,v) in changes:
