@@ -9,11 +9,11 @@ from cogent.app.parameters import *
 from os import remove,system,mkdir,rmdir,removedirs,getcwd, walk
 
 __author__ = "Greg Caporaso and Sandra Smit"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2012, The Cogent Project"
 __credits__ = ["Greg Caporaso", "Sandra Smit", "Gavin Huttley",
                     "Rob Knight", "Daniel McDonald"]
 __license__ = "GPL"
-__version__ = "1.4.1"
+__version__ = "1.5.2"
 __maintainer__ = "Sandra Smit"
 __email__ = "sandra.smit@colorado.edu"
 __status__ = "Development"
@@ -428,6 +428,15 @@ class CommandLineApplicationTests(TestCase):
         """CLAppTester: getHelp() functions as expected """
         app = CLAppTester()
         self.assertEqual(app.getHelp(),'Duh')
+    
+    def test_handle_app_result_build_failure(self):
+        """_handle_app_result_build_failure called when CommandLineAppResult() fails
+        """
+        app = CLAppTester_bad_fixed_file()
+        self.assertRaises(ApplicationError,app)
+        
+        app = CLAppTester_bad_fixed_file_w_handler()
+        self.assertEqual(app(),"Called self._handle_app_result_build_failure")
         
     def test_error_on_missing_executable(self):
         """CLAppTester: Useful error message on executable not found
@@ -925,6 +934,11 @@ class CommandLineApplicationTests(TestCase):
         app = CLAppTester()
         app._command = None
         self.assertRaises(ApplicationError, app._get_base_command)
+    
+    def test_rejected_exit_status(self):
+        """CLAppTester_reject_exit_status results in useful error """
+        app = CLAppTester_reject_exit_status()
+        self.assertRaises(ApplicationError,app)
 
     def test_getTmpFilename(self):
         """TmpFilename should return filename of correct length"""
@@ -1162,6 +1176,33 @@ class CLAppTester(CommandLineApplication):
 class CLAppTester_no_working_dir(CLAppTester):
     _working_dir = None
 
+class CLAppTester_reject_exit_status(CLAppTester):
+    def _accept_exit_status(self,exit_status):
+        return False
+
+class CLAppTester_bad_fixed_file(CLAppTester):
+    
+    def _get_result_paths(self,data):
+        
+        if self.Parameters['-F'].isOn():
+            param_path = ''.join([self.WorkingDir,self.Parameters['-F'].Value])
+        else:
+            param_path = None
+        
+        result = {}
+        result['fixed_file'] = ResultPath(Path='/tmp/fixed.txt')
+        result['fixed_file_bad'] = ResultPath(Path='/tmp/i_dont_exist.txt')
+        result['parameterized_file'] = ResultPath(Path=param_path,\
+            IsWritten=self.Parameters['-F'].isOn())
+        result['base_dep_1'] = ResultPath(Path=self._build_name(suffix='.1')) 
+        result['base_dep_2'] = ResultPath(Path=self._build_name(suffix='.2'))
+        return result
+        
+class CLAppTester_bad_fixed_file_w_handler(CLAppTester_bad_fixed_file):
+    def _handle_app_result_build_failure(self,out,err,exit_status,result_paths):
+        return "Called self._handle_app_result_build_failure"
+
+        
 class CLAppTester_space_in_command(CLAppTester):
     _command = '"/tmp/CLApp Tester.py"'
 
